@@ -23,7 +23,8 @@ var (
 
 			`\[NodeAlphaFeature:VolumeSubpathEnvExpansion\]`, // flag gate is off
 			`\[Feature:IPv6DualStack.*\]`,
-			`version v1 should create Endpoints and EndpointSlices for Pods matching a Service`, // off by default.
+			`\[Feature:ImmutableEphemeralVolume\]`,      // flag gate is off
+			`\[Feature:ServiceAccountIssuerDiscovery\]`, // flag gate is off
 		},
 		// tests for features that are not implemented in openshift
 		"[Disabled:Unimplemented]": {
@@ -47,7 +48,6 @@ var (
 			`\[Feature:ImageQuota\]`,                    // Quota isn't turned on by default, we should do that and then reenable these tests
 			`\[Feature:Audit\]`,                         // Needs special configuration
 			`\[Feature:LocalStorageCapacityIsolation\]`, // relies on a separate daemonset?
-			`\[sig-cluster-lifecycle\]`,                 // cluster lifecycle test require a different kind of upgrade hook.
 			`\[sig-cloud-provider-gcp\]`,                // these test require a different configuration - note that GCE tests from the sig-cluster-lifecycle were moved to the sig-cloud-provider-gcpcluster lifecycle see https://github.com/kubernetes/kubernetes/commit/0b3d50b6dccdc4bbd0b3e411c648b092477d79ac#diff-3b1910d08fb8fd8b32956b5e264f87cb
 			`\[Feature:StatefulUpgrade\]`,               // related to cluster lifecycle (in e2e/lifecycle package) and requires an upgrade hook we don't use
 
@@ -64,42 +64,36 @@ var (
 		// tests that are known broken and need to be fixed upstream or in openshift
 		// always add an issue here
 		"[Disabled:Broken]": {
-			`mount an API token into pods`,                                               // We add 6 secrets, not 1
-			`ServiceAccounts should ensure a single API token exists`,                    // We create lots of secrets
-			`unchanging, static URL paths for kubernetes api services`,                   // the test needs to exclude URLs that are not part of conformance (/logs)
-			`Simple pod should handle in-cluster config`,                                 // kubectl cp is not preserving executable bit
-			`Services should be able to up and down services`,                            // we don't have wget installed on nodes
-			`Network should set TCP CLOSE_WAIT timeout`,                                  // possibly some difference between ubuntu and fedora
-			`Services should be able to create a functioning NodePort service`,           // https://bugzilla.redhat.com/show_bug.cgi?id=1711603
-			`\[NodeFeature:Sysctls\]`,                                                    // needs SCC support
-			`should check kube-proxy urls`,                                               // previously this test was skipped b/c we reported -1 as the number of nodes, now we report proper number and test fails
-			`SSH`,                                                                        // TRIAGE
-			`should implement service.kubernetes.io/service-proxy-name`,                  // this is an optional test that requires SSH. sig-network
-			`should idle the service and DeploymentConfig properly`,                      // idling with a single service and DeploymentConfig [Conformance]
-			`should answer endpoint and wildcard queries for the cluster`,                // currently not supported by dns operator https://github.com/openshift/cluster-dns-operator/issues/43
-			`should allow ingress access on one named port`,                              // https://bugzilla.redhat.com/show_bug.cgi?id=1711602
-			`ClusterDns \[Feature:Example\] should create pod that uses dns`,             // https://bugzilla.redhat.com/show_bug.cgi?id=1711601
-			`PreemptionExecutionPath runs ReplicaSets to verify preemption running path`, // https://bugzilla.redhat.com/show_bug.cgi?id=1711606
-			`TaintBasedEvictions`,                                                        // https://bugzilla.redhat.com/show_bug.cgi?id=1711608
-			`recreate nodes and ensure they function upon restart`,                       // https://bugzilla.redhat.com/show_bug.cgi?id=1756428
-			`\[Driver: iscsi\]`,                                                          // https://bugzilla.redhat.com/show_bug.cgi?id=1711627
-			// TODO(workloads): reenable
-			`SchedulerPreemption`,
+			`mount an API token into pods`,                                // We add 6 secrets, not 1
+			`ServiceAccounts should ensure a single API token exists`,     // We create lots of secrets
+			`unchanging, static URL paths for kubernetes api services`,    // the test needs to exclude URLs that are not part of conformance (/logs)
+			`Services should be able to up and down services`,             // we don't have wget installed on nodes
+			`Network should set TCP CLOSE_WAIT timeout`,                   // possibly some difference between ubuntu and fedora
+			`\[NodeFeature:Sysctls\]`,                                     // needs SCC support
+			`should check kube-proxy urls`,                                // previously this test was skipped b/c we reported -1 as the number of nodes, now we report proper number and test fails
+			`SSH`,                                                         // TRIAGE
+			`should implement service.kubernetes.io/service-proxy-name`,   // this is an optional test that requires SSH. sig-network
+			`should idle the service and DeploymentConfig properly`,       // idling with a single service and DeploymentConfig
+			`should answer endpoint and wildcard queries for the cluster`, // currently not supported by dns operator https://github.com/openshift/cluster-dns-operator/issues/43
+			`should allow ingress access on one named port`,               // https://bugzilla.redhat.com/show_bug.cgi?id=1711602
+			`recreate nodes and ensure they function upon restart`,        // https://bugzilla.redhat.com/show_bug.cgi?id=1756428
+			`\[Driver: iscsi\]`,                                           // https://bugzilla.redhat.com/show_bug.cgi?id=1711627
 
-			// requires a 1.14 kubelet, enable when rhcos is built for 4.2
-			"when the NodeLease feature is enabled",
 			"RuntimeClass should reject",
 
+			`Services should implement service.kubernetes.io/headless`,       // requires SSH access to function, needs to be refactored
+			`ClusterDns \[Feature:Example\] should create pod that uses dns`, // doesn't use bindata, not part of kube test binary
+			`Simple pod should handle in-cluster config`,                     // kubectl cp doesn't work or is not preserving executable bit, we have this test already
+
 			// TODO(node): configure the cri handler for the runtime class to make this work
 			"should run a Pod requesting a RuntimeClass with a configured handler",
 			"should reject a Pod requesting a RuntimeClass with conflicting node selector",
 			"should run a Pod requesting a RuntimeClass with scheduling",
 
-			// TODO(sdn): reenable when openshift/sdn is rebased to 1.16
-			`Services should implement service.kubernetes.io/headless`,
+			// A fix is in progress: https://github.com/openshift/origin/pull/24709
+			`Multi-AZ Clusters should spread the pods of a replication controller across zones`,
 
-			// TODO(sdn): test pod fails to connect in 1.16
-			`should allow ingress access from updated pod`,
+			`Cluster should restore itself after quorum loss`, // https://bugzilla.redhat.com/show_bug.cgi?id=1837157
 		},
 		// tests that may work, but we don't support them
 		"[Disabled:Unsupported]": {
@@ -137,11 +131,15 @@ var (
 			`should allow starting 95 pods per node`,
 			`DynamicProvisioner should test that deleting a claim before the volume is provisioned deletes the volume`, // test is very disruptive to other tests
 
-			`Multi-AZ Clusters should spread the pods`, // spreading is a priority, not a predicate, and if the node is temporarily full the priority will be ignored
+			`Multi-AZ Clusters should spread the pods of a service across zones`, // spreading is a priority, not a predicate, and if the node is temporarily full the priority will be ignored
 
 			`Should be able to support the 1\.7 Sample API Server using the current Aggregator`, // down apiservices break other clients today https://bugzilla.redhat.com/show_bug.cgi?id=1623195
 
 			`\[Feature:HPA\] Horizontal pod autoscaling \(scale resource: CPU\) \[sig-autoscaling\] ReplicationController light Should scale from 1 pod to 2 pods`,
+
+			`should prevent Ingress creation if more than 1 IngressClass marked as default`, // https://bugzilla.redhat.com/show_bug.cgi?id=1822286
+
+			`\[sig-network\] IngressClass \[Feature:Ingress\] should set default value on new IngressClass`, //https://bugzilla.redhat.com/show_bug.cgi?id=1833583
 		},
 		"[Skipped:azure]": {
 			"Networking should provide Internet connection for containers", // Azure does not allow ICMP traffic to internet.
@@ -150,6 +148,12 @@ var (
 			`\[sig-storage\] In-tree Volumes \[Driver: azure\] \[Testpattern: Inline-volume`,
 			`\[sig-storage\] In-tree Volumes \[Driver: azure\] \[Testpattern: Pre-provisioned PV`,
 		},
+		"[Skipped:ovirt]": {
+			// https://bugzilla.redhat.com/show_bug.cgi?id=1838751
+			`\[sig-network\] Networking Granular Checks: Services should function for endpoint-Service`,
+			`\[sig-network\] Networking Granular Checks: Services should function for node-Service`,
+			`\[sig-network\] Networking Granular Checks: Services should function for pod-Service`,
+		},
 		"[Skipped:gce]": {
 			// Requires creation of a different compute instance in a different zone and is not compatible with volumeBindingMode of WaitForFirstConsumer which we use in 4.x
 			`\[sig-scheduling\] Multi-AZ Cluster Volumes \[sig-storage\] should only be allowed to provision PDs in zones where nodes exist`,
@@ -178,6 +182,28 @@ var (
 			// should be serial if/when it's re-enabled
 			`\[HPA\] Horizontal pod autoscaling \(scale resource: Custom Metrics from Stackdriver\)`,
 		},
+		// tests that don't pass under openshift-sdn but that are expected to pass
+		// with other network plugins (particularly ovn-kubernetes)
+		"[Skipped:Network/OpenShiftSDN]": {
+			`NetworkPolicy between server and client should allow egress access on one named port`, // not yet implemented
+		},
+		// tests that don't pass under openshift-sdn multitenant mode
+		"[Skipped:Network/OpenShiftSDN/Multitenant]": {
+			`\[Feature:NetworkPolicy\]`, // not compatible with multitenant mode
+			`\[sig-network\] Services should preserve source pod IP for traffic thru service cluster IP`, // known bug, not planned to be fixed
+		},
+		// tests that don't pass under OVN Kubernetes
+		"[Skipped:Network/OVNKubernetes]": {
+			// https://jira.coreos.com/browse/SDN-510: OVN-K doesn't support session affinity
+			`\[sig-network\] Networking Granular Checks: Services should function for client IP based session affinity: http`,
+			`\[sig-network\] Networking Granular Checks: Services should function for client IP based session affinity: udp`,
+			`\[sig-network\] Services should be able to switch session affinity for NodePort service`,
+			`\[sig-network\] Services should be able to switch session affinity for service with type clusterIP`,
+			`\[sig-network\] Services should have session affinity work for NodePort service`,
+			`\[sig-network\] Services should have session affinity work for service with type clusterIP`,
+			`\[sig-network\] Services should have session affinity timeout work for NodePort service`,
+			`\[sig-network\] Services should have session affinity timeout work for service with type clusterIP`,
+		},
 		"[Skipped:ibmcloud]": {
 			// skip Gluster tests (not supported on ROKS worker nodes)
 			// https://bugzilla.redhat.com/show_bug.cgi?id=1825009 - e2e: skip Glusterfs-related tests upstream for rhel7 worker nodes
@@ -228,36 +254,45 @@ var (
 			// https://bugzilla.redhat.com/show_bug.cgi?id=1825372
 			`Pod Container Status should never report success for a pending container`,
 		},
-		// tests that don't pass under openshift-sdn but that are expected to pass
-		// with other network plugins (particularly ovn-kubernetes)
-		"[Skipped:Network/OpenShiftSDN]": {
-			`NetworkPolicy between server and client should allow egress access on one named port`, // not yet implemented
+		"[sig-node]": {
+			`\[NodeConformance\]`,
+			`NodeLease`,
+			`lease API`,
+			`\[NodeFeature`,
+			`\[NodeAlphaFeature`,
+			`Probing container`,
+			`Security Context When creating a`,
+			`Downward API should create a pod that prints his name and namespace`,
+			`Liveness liveness pods should be automatically restarted`,
+			`Secret should create a pod that reads a secret`,
 		},
-		// tests that don't pass under openshift-sdn multitenant mode
-		"[Skipped:Network/OpenShiftSDN/Multitenant]": {
-			`\[Feature:NetworkPolicy\]`, // not compatible with multitenant mode
-			`\[sig-network\] Services should preserve source pod IP for traffic thru service cluster IP`, // known bug, not planned to be fixed
+		"[sig-cluster-lifecycle]": {
+			`Feature:ClusterAutoscalerScalability`,
+			`recreate nodes and ensure they function`,
 		},
-		// tests that don't pass under OVN Kubernetes
-		"[Skipped:Network/OVNKubernetes]": {
-			// https://jira.coreos.com/browse/SDN-510: OVN-K doesn't support session affinity
-			`\[sig-network\] Networking Granular Checks: Services should function for client IP based session affinity: http`,
-			`\[sig-network\] Networking Granular Checks: Services should function for client IP based session affinity: udp`,
-			`\[sig-network\] Services should be able to switch session affinity for NodePort service`,
-			`\[sig-network\] Services should be able to switch session affinity for service with type clusterIP`,
-			`\[sig-network\] Services should have session affinity work for NodePort service`,
-			`\[sig-network\] Services should have session affinity work for service with type clusterIP`,
-			// SDN-587: OVN-Kubernetes doesn't support hairpin services
-			`\[sig-network\] Services should allow pods to hairpin back to themselves through services`,
-			`\[sig-network\] Networking Granular Checks: Services should function for endpoint-Service`,
-			// https://github.com/ovn-org/ovn-kubernetes/issues/928
-			`\[sig-network\] Services should be rejected when no endpoints exist`,
-			`\[cli\] oc explain networking types should contain proper fields description for special networking types`,
+		"[sig-arch]": {
+			// not run, assigned to arch as catch-all
+			`\[Feature:GKELocalSSD\]`,
+			`\[Feature:GKENodePool\]`,
 		},
-		"[Suite:openshift/scalability]": {},
-		// tests that replace the old test-cmd script
-		"[Suite:openshift/test-cmd]": {
-			`\[Suite:openshift/test-cmd\]`,
+
+		"[Disabled:sig-cli]": {
+			// Removed in 1.18, skipping those to merge oc rebase before origin gets rebased to 1.18
+			// TODO(jchaloup): once origin is rebased to 1.18, remove the lines
+			"Kubectl alpha client Kubectl run CronJob should create a CronJob",
+			"Kubectl client Simple pod should support inline execution and attach",
+			"Kubectl client Simple pod should contain last line of the log",
+			"Kubectl client Kubectl logs should be able to retrieve and filter logs",
+			"Kubectl client Kubectl run default should create an rc or deployment from an image",
+			"Kubectl client Kubectl run rc should create an rc from an image",
+			"Kubectl client Kubectl rolling-update should support rolling-update to same image",
+			"Kubectl client Kubectl run deployment should create a deployment from an image",
+			"Kubectl client Kubectl run job should create a job from an image when restart is OnFailure",
+			"Kubectl client Kubectl run CronJob should create a CronJob",
+			"Kubectl client Kubectl run pod should create a pod from an image when restart is Never",
+			"Kubectl client Kubectl replace should update a single-container pod's image",
+			"Kubectl client Kubectl run --rm job should create a job from an image, then delete the job",
+			"Kubectl client Update Demo should do a rolling update of a replication controller",
 		},
 	}
 
@@ -270,7 +305,6 @@ var (
 		`\[Skipped\]`,
 		`\[Slow\]`,
 		`\[Flaky\]`,
-		`\[local\]`,
-		`\[Suite:openshift/test-cmd\]`,
+		`\[Local\]`,
 	}
 )
